﻿using SqlSugar;
using System.ComponentModel;

namespace HotlineQuery.Sdk
{
    /// <summary>
    /// 公告
    /// </summary>
    [SugarTable("bulletin")]
    public class Bulletin
    {
        [SugarColumn(IsPrimaryKey = true)]
        public string Id { get; set; }

        public string Title { get; set; }

        public string Content { get; set; }

        public string BulletinTypeId { get; set; }

        public string BulletinTypeName { get; set; }

        /// <summary>
        /// 阅读量
        /// </summary>
        public int ReadedNum { get; set; }

        /// <summary>
        /// 通知时间
        /// </summary>
        public DateTime? BulletinTime { get; set; }

        /// <summary>
        /// 失效时间
        /// </summary>
        public DateTime LoseEfficacyTime { get; set; }

        /// <summary>
        /// 公告状态
        /// </summary>
        public EBulletinState BulletinState { get; set; }

        /// <summary>
        /// 发布范围（多选） 位枚举  EPushRange
        /// </summary>
        [SugarColumn(ColumnDataType = "json", IsJson = true, IsNullable = true)]
        public List<Kv>? PushRanges { get; set; }

        /// <summary>
        /// 来源单位ID
        /// </summary>
        public string SourceOrgId { get; set; }

        /// <summary>
        /// 来源单位名称
        /// </summary>
        public string SourceOrgName { get; set; }

        /// <summary>
        /// 提交时间
        /// </summary>
        public DateTime? CommitTime { get; set; }

        /// <summary>
        /// 审核意见
        /// </summary>
        public string? ExaminOpinion { get; set; }

        /// <summary>
        /// 审核人
        /// </summary>
        public string? ExaminManId { get; set; }

        /// <summary>
        /// 审核时间
        /// </summary>
        public DateTime? ExaminTime { get; set; }

        /// <summary>
        /// 是否上架
        /// </summary>
        public bool? IsArrive { get; set; }

        /// <summary>
        /// 创建时间
        /// </summary>
        public DateTime CreationTime { get; set; }

    }
    public enum EBulletinState
    {
        /// <summary>
        /// 草稿
        /// </summary>
        [Description("草稿")]
        Draft = 0,
        /// <summary>
        /// 审批中
        /// </summary>
        [Description("审批中")]
        InReview = 1,
        /// <summary>
        /// 审批通过
        /// </summary>
        [Description("审批通过")]
        ReviewPass = 2,
        /// <summary>
        /// 审批驳回
        /// </summary>
        [Description("审批驳回")]
        ReviewNoPass = 3,
    }

    public class Kv
    {
        public Kv()
        {
        }

        public Kv(string key, string value)
        {
            Key = key;
            Value = value;
        }

        public string Key { get; set; }
        public string Value { get; set; }
    }
}
