﻿using SqlSugar;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace HotlineQuery.Sdk
{
    /// <summary>
    /// 公告
    /// </summary>
    [SugarTable("order")]
    public class HotlineOrder
    {
        [SugarColumn(IsPrimaryKey = true)]
        public string Id { get; set; }

        /// <summary>
        /// 受理类型
        /// </summary>
        public string? AcceptType { get; set; }

        public string? AcceptTypeCode { get; set; }

        public string Title { get; set; }

        /// <summary>
        /// 来源渠道（电话、网站、APP等）
        /// </summary>
        public string? SourceChannel { get; set; }

        public string? SourceChannelCode { get; set; }

        /// <summary>
        /// 来电号码
        /// </summary>
        public string? FromPhone { get; set; }

        /// <summary>
        /// 来电/信人姓名
        /// </summary>
        public string? FromName { get; set; }

        /// <summary>
        /// 联系电话
        /// </summary>
        public string? Contact { get; set; }

        public string? ContactMask { get; set; }

        /// <summary>
        /// 是否保密
        /// </summary>
        public bool IsSecret { get; set; }

        /// <summary>
        /// 热点
        /// </summary>
        public string? HotspotId { get; set; }

        public string? HotspotName { get; set; }

        public string? HotspotSpliceName { get; set; }

        /// <summary>
        /// 外部数据（为前端提供级联功能）
        /// </summary>
        public string? HotspotExternal { get; set; }

        /// <summary>
        /// 诉求内容
        /// </summary>
        [SugarColumn(ColumnDataType = "varchar(8000)")]
        public string Content { get; set; }

        /// <summary>
        /// 同步省工单编号和省上传下来的工单都用这个字段
        /// </summary>
        public string? ProvinceNo { get; set; }

        /// <summary>
        /// 外部工单唯一标识
        /// </summary>
        public string? ExternalId { get; set; }

        /// <summary>
        /// 工单状态
        /// </summary>
        public EOrderStatus Status { get; set; }

        /// <summary>
        /// 来源，区分省平台或110等其他平台同步过来的工单
        /// </summary>
        public ESource Source { get; set; }

        /// <summary>
        /// 工单编码（20220101000001）
        /// </summary>
        public string? No { get; set; }

        /// <summary>
        /// 是否已撤销
        /// </summary>
        public bool IsCancel { get; set; }

        /// <summary>
        /// 市民查询密码
        /// </summary>
        public string? Password { get; set; }

        /// <summary>
        /// 企业名称
        /// </summary>
        public string? EnterpriseName { get; set; }

        /// <summary>
        /// 完整地址
        /// </summary>
        public string? FullAddress { get; set; }

        /// <summary>
        /// 企业Code
        /// </summary>
        public string? EnterpriseCode { get; set; }


        /// <summary>
        /// 专班名称
        /// </summary>
        public string? ZhuanBanMingCheng { get; set; }

        /// <summary>
        /// 专班Code
        /// </summary>
        public string? ZhuanBanCode { get; set; }

        /// <summary>
        /// 工单开始时间(受理/接办时间=流程开启时间)
        /// </summary>
        public DateTime? StartTime { get; set; }

        /// <summary>
        /// 超期时间（期满时间）
        /// </summary>
        public DateTime? ExpiredTime { get; set; }

        /// <summary>
        /// 即将超期时间
        /// </summary>
        public DateTime? NearlyExpiredTime { get; set; }

        /// <summary>
        /// 归档时间（暂为流程结束时间，因流程结束自动归档）
        /// </summary>
        public DateTime? FiledTime { get; set; }

        /// <summary>
        /// 实际办理节点签收时间
        /// </summary>
        public DateTime? ActualHandleStepAcceptTime { get; set; }

        /// <summary>
        /// 实际办理时间
        /// </summary>
        public DateTime? ActualHandleTime { get; set; }

        /// <summary>
        /// 实际办理人id
        /// </summary>
        public string? ActualHandlerId { get; set; }

        /// <summary>
        /// 实际办理人名称
        /// </summary>
        public string? ActualHandlerName { get; set; }

        /// <summary>
        /// 实际办理部门名称
        /// </summary>
        public string? ActualHandleOrgName { get; set; }

        /// <summary>
        /// 实际办理部门编码
        /// </summary>
        public string? ActualHandleOrgCode { get; set; }

        /// <summary>
        /// 实际办理部门行政区划编码
        /// </summary>
        public string? ActualHandleOrgAreaCode { get; set; }

        /// <summary>
        /// 实际办理部门行政区划名称
        /// </summary>
        public string? ActualHandleOrgAreaName { get; set; }

        /// <summary>
        /// 创建时间
        /// </summary>
        public DateTime CreationTime { get; set; }

        /// <summary>
        /// 实际办理意见（办理中...or 最终办理意见）
        /// </summary>
        public string ActualOpinion { get; set; } = "办理中...";

        /// <summary>
        /// 附件
        /// </summary>
        public List<FileDto>? Additions { get; set; } = new();

    }
    public enum EOrderStatus
    {
        /// <summary>
        /// 待受理
        /// </summary>
        [Description("待受理")]
        WaitForAccept = 0,

        /// <summary>
        /// 已开启流程,退回到开始节点
        /// 待受理，可编辑
        /// </summary>
        [Description("退回待受理")]
        BackToUnAccept = 1,

        /// <summary>
        /// 已开启流程,特提到开始节点
        /// 待受理，可编辑
        /// </summary>
        [Description("特提待受理")]
        SpecialToUnAccept = 2,

        /// <summary>
        /// 已开启流程,移交开始节点
        /// 待受理，可编辑
        /// </summary>
        [Description("移交待受理")]
        HandOverToUnAccept = 3,

        /// <summary>
        /// 退回省平台（锁定，不可操作）
        /// </summary>
        [Description("退回省平台")]
        BackToProvince = 9,

        /// <summary>
        /// 办理中
        /// </summary>
        [Description("办理中")]
        Handling = 100,

        /// <summary>
        /// 特提信件
        /// </summary>
        [Description("特提信件")]
        Special = 101,

        /// <summary>
        /// 退回信件
        /// </summary>
        [Description("退回信件")]
        SendBack = 102,

        /// <summary>
        /// 移交信件
        /// </summary>
        [Description("移交信件")]
        HandOver = 103,

        /// <summary>
        /// 特提审批中
        /// </summary>
        [Description("特提审批中")]
        SpecialAudit = 104,

        /// <summary>
        /// 退回审批中
        /// </summary>
        [Description("退回审批中")]
        SendBackAudit = 105,

        /// <summary>
        /// 会签中
        /// </summary>
        [Description("会签中")]
        Countersigning = 200,

        /// <summary>
        /// 已归档
        /// </summary>
        [Description("已归档")]
        Filed = 300,

        /// <summary>
        /// 已发布
        /// </summary>
        [Description("已发布")]
        Published = 400,

        /// <summary>
        /// 已回访
        /// </summary>
        [Description("已回访")]
        Visited = 500,
    }

    public enum ESource
    {
        /// <summary>
        /// 热线平台工单
        /// </summary>
        Hotline = 0,

        /// <summary>
        /// 门户网站
        /// </summary>
        WebPortal = 2,

        /// <summary>
        /// 热线平台导入工单
        /// </summary>
        HotlineImport = 1,

        /// <summary>
        /// 省平台直派
        /// </summary>
        ProvinceStraight = 100,

        /// <summary>
        /// 110同步工单
        /// </summary>
        Police110 = 200,

        /// <summary>
        /// 市州互转--泸州 
        /// </summary>
        CityDataExchangeLz = 300,

        /// <summary>
        /// 市州互转--宜宾
        /// </summary>
        CityDataExchangeYB = 301,

        /// <summary>
        /// 市州互转--自贡
        /// </summary>
        CityDataExchangeZG = 302,

        /// <summary>
        /// 市州互转--内江
        /// </summary>
        CityDataExchangeNJ = 303,

        /// <summary>
        /// 宜宾融媒体
        /// </summary>
        ConvergenceMedia = 400,

        /// <summary>
        /// i宜宾
        /// </summary>
        IYIBIN = 401,

        /// <summary>
        /// 智慧宜宾
        /// </summary>
        ZHYB = 402,

        /// <summary>
        /// 综治平台
        /// </summary>
        ZZPT = 403,

        /// <summary>
        /// 网络理政—市民中心大厅
        /// </summary>
        WLLZ = 404,

        #region 导入类型（>=500  <530为导入来源）
        /// <summary>
        /// 麻辣社区导入
        /// </summary>
        [Description("麻辣社区")]
        MLSQ = 500,

        /// <summary>
        /// 人民网
        /// </summary>
        [Description("人民网")]
        RMW = 501,

        /// <summary>
        /// 省长信箱
        /// </summary>
        [Description("省长信箱")]
        SZXX = 502,

        /// <summary>
        /// 问政四川
        /// </summary>
        [Description("问政四川")]
        WZSC = 529,
        #endregion
    }

    public class FileDto
    {
        /// <summary>
		/// 附件名称
		/// </summary>
		public string? Name { get; set; }

        /// <summary>
        /// 附件KEY
        /// </summary>
        public string? Key { get; set; }


        /// <summary>
        /// 附件流程KEY
        /// </summary>
        public string? FlowKey { get; set; }


        /// <summary>
        /// 附件类型
        /// </summary>
        public string? Type { get; set; }

        /// <summary>
        /// 部门ID
        /// </summary>
        public string? OrgId { get; set; }

        /// <summary>
        /// 部门名称
        /// </summary>
        public string? OrgName { get; set; }

        /// <summary>
        /// 上传人Id
        /// </summary>
        public string? UserId { get; set; }

        /// <summary>
        /// 上传人名称
        /// </summary>
        public string? UserName { get; set; }


        /// <summary>
        /// 是否公开
        /// </summary>
        public int? Publicity { get; set; }


        /// <summary>
        /// 附件分类
        /// </summary>
        public string? Classify { get; set; }

        /// <summary>
        /// 附件
        /// </summary>
        public string? Additions { get; set; }

        /// <summary>
        /// 附件路径
        /// </summary>
        public string? Path { get; set; }

    }
}
